==> next-ft-api-client-3.13.0.tgz: package/test/content.test.js <==
/*global describe, it*/
'use strict';

GLOBAL.fetch = require('node-fetch');
var api = require('../main');
var sinon = require('sinon');
var nock = require('nock');
var expect = require('chai').expect;

nock('http://api.ft.com')
	.get('/content?isAnnotatedBy=http://api.ft.com/things/5c7592a8-1f0c-11e4-b0cb-b2227cce2b54')
	.reply(200, require('./fixtures/capi-v2-is-annotated-by'))

	.get('/content/12dc0348-d780-11e4-94b1-00144feab7de')
	.reply(200, require('./fixtures/capi-v2-article'))

	.get('/content/a0d9ce37-f3f0-3999-8be1-342d3988438c')
	.times(2)
	.reply(200, require('./fixtures/capi-v2-article-a0d9ce37'))

	.get('/content/24d3b305-9f9d-3fb8-9ddc-f33a22eeb248')
	.times(2)
	.reply(200, require('./fixtures/capi-v2-article-24d3b305'))

	.get('/lists/3c99c2ba-a6ae-11e2-95b1-00144feabdc0')
	.reply(200, require('./fixtures/capi-v2-lists'))

	.get('/organisations/89a11e71-2651-3ded-bd99-cbf02cddcfb4')
	.reply(200, require('./fixtures/capi-v2-organisation'))

	.post('/content/search/v1')
	.reply(200, require('./fixtures/sapi-v1-empty'));

nock('https://elastic-search-host')
	.post('/v2_api_v2/item/_mget', { ids: ['12dc0348-d780-11e4-94b1-00144feab7de'] })
	.reply(200, require('./fixtures/capi-v2-article-elastic'))
	.post('/v2_api_v2/item/_mget', { ids: ["a0d9ce37-f3f0-3999-8be1-342d3988438c", "24d3b305-9f9d-3fb8-9ddc-f33a22eeb248"] })
	.reply(200, require('./fixtures/capi-v2-article-elastic-two'))
	.post('/v1_api_v2/item/_search')
	.times(3)
	.reply(200, require('./fixtures/sapi-v1-elastic'));

describe('content', function() {
	it('should return content', function() {
		return api.content({
				uuid: '12dc0348-d780-11e4-94b1-00144feab7de'
			})
			.then(function(article) {
				expect(article.title).to.be.a.string;
			});
	});

	it('should optionally get content from elastic search', function() {
		return api.content({
				uuid: '12dc0348-d780-11e4-94b1-00144feab7de',
				useElasticSearch: true
			})
			.then(function(article) {
				expect(article.title).to.be.a.string;
			});
	});

	it('should support mgets with elastic search', function() {
		return api.content({
			uuid: ['a0d9ce37-f3f0-3999-8be1-342d3988438c', '24d3b305-9f9d-3fb8-9ddc-f33a22eeb248'],
			useElasticSearch: true
		});
	});

	it('should support mgets without elastic search', function() {
		return api.content({
			uuid: ['a0d9ce37-f3f0-3999-8be1-342d3988438c', '24d3b305-9f9d-3fb8-9ddc-f33a22eeb248']
		});
	});
});

describe('organisation', function() {
	it('should return content', function() {
		return api.organisations({
				uuid: '89a11e71-2651-3ded-bd99-cbf02cddcfb4'
			})
			.then(function(article) {
				expect(article.title).to.be.a.string;
			});
	});
});

describe('lists', function() {
	it('should return content', function() {
		return api.lists({
				uuid: '3c99c2ba-a6ae-11e2-95b1-00144feabdc0'
			})
			.then(function(list) {
				expect(list.title).to.be.a.string;
				expect(list.items.length).to.equal(3);
			});
	});
});

describe('is-annotated-by', function() {
	it('should return content', function() {
		return api.contentAnnotatedBy({
				uuid: '5c7592a8-1f0c-11e4-b0cb-b2227cce2b54'
			})
			.then(function(articles) {
				expect(articles.length).to.equal(2);
			});
	});
});

describe('search-legacy', function() {
	it('should behave gracefully when there are no results', function() {
		return api.searchLegacy({
			query: 'no results please'
		})
			.then(function(articles) {
				expect(articles.length).to.equal(0);
				expect(articles.indexCount).to.equal(0);
			});
	});
	it("should support elastic search", function() {
		return api.searchLegacy({
			query: 'peopleId:"TnN0ZWluX1BOX1BvbGl0aWNpYW5fMjcx-UE4="',
			useElasticSearch: true
		})
			.then(function(articles) {
				expect(articles.length).to.equal(50);
				expect(articles.indexCount).to.equal(7783);

			});
	});

	it("should support complex elastic searches", function() {
		sinon.spy(GLOBAL, 'fetch');

		return api.searchLegacy({
			query: {test: true},
			fields: ['test'],
			useElasticSearch: true
		})
			.then(function () {
				var elasticOpts = JSON.parse(GLOBAL.fetch.args[0][1].body);
				expect(elasticOpts.fields[0]).to.equal('test');
				expect(elasticOpts.query.test).to.be.true;
				GLOBAL.fetch.restore();
			});

	});

	it("should ignore items tagged as podcast by default", function() {
		sinon.spy(GLOBAL, 'fetch');

		return api.searchLegacy({
			query: 'peopleId:"TnN0ZWluX1BOX1BvbGl0aWNpYW5fMjcx-UE4="',
			useElasticSearch: true
		})
			.then(function () {
				var elasticOpts = JSON.parse(GLOBAL.fetch.args[0][1].body);
				expect(elasticOpts.query.bool.must_not.term).to.an('object');
				expect(elasticOpts.query.bool.must_not.term).to.have.keys('item.metadata.sections.term.name');
				GLOBAL.fetch.restore();
			});

	});
});

==> next-ft-api-client-3.17.0.tgz: package/test/content.test.js <==
/*global describe, it*/
'use strict';

GLOBAL.fetch = require('node-fetch');
var api = require('../main');
var sinon = require('sinon');
var nock = require('nock');
var expect = require('chai').expect;

nock('http://api.ft.com')
	.get('/content?isAnnotatedBy=http://api.ft.com/things/5c7592a8-1f0c-11e4-b0cb-b2227cce2b54')
	.reply(200, require('./fixtures/capi-v2-is-annotated-by'))

	.get('/content/12dc0348-d780-11e4-94b1-00144feab7de')
	.reply(200, require('./fixtures/capi-v2-article'))

	.get('/content/a0d9ce37-f3f0-3999-8be1-342d3988438c')
	.times(2)
	.reply(200, require('./fixtures/capi-v2-article-a0d9ce37'))

	.get('/content/24d3b305-9f9d-3fb8-9ddc-f33a22eeb248')
	.times(2)
	.reply(200, require('./fixtures/capi-v2-article-24d3b305'))

	.get('/lists/3c99c2ba-a6ae-11e2-95b1-00144feabdc0')
	.reply(200, require('./fixtures/capi-v2-lists'))

	.get('/organisations/89a11e71-2651-3ded-bd99-cbf02cddcfb4')
	.reply(200, require('./fixtures/capi-v2-organisation'))

	.post('/content/search/v1')
	.reply(200, require('./fixtures/sapi-v1-empty'));

nock('https://next-elastic.ft.com')
	.post('/v2_api_v2/item/_mget', { ids: ['12dc0348-d780-11e4-94b1-00144feab7de'] })
	.reply(200, require('./fixtures/capi-v2-article-elastic'))
	.post('/v2_api_v2/item/_mget', { ids: ["a0d9ce37-f3f0-3999-8be1-342d3988438c", "24d3b305-9f9d-3fb8-9ddc-f33a22eeb248"] })
	.reply(200, require('./fixtures/capi-v2-article-elastic-two'))
	.post('/v1_api_v2/item/_search')
	.times(3)
	.reply(200, require('./fixtures/sapi-v1-elastic'));

describe('content', function() {
	it('should optionally get content from elastic search', function() {
		return api.content({ uuid: '12dc0348-d780-11e4-94b1-00144feab7de' })
			.then(function(article) {
				expect(article.title).to.be.a.string;
			});
	});

	it('should support mgets with elastic search', function() {
		return api.content({
			uuid: ['a0d9ce37-f3f0-3999-8be1-342d3988438c', '24d3b305-9f9d-3fb8-9ddc-f33a22eeb248']
		});
	});

	it('should just return nothing if requested nothing', function() {
		return api.content({
			uuid: []
		})
			.then(result => {
				expect(result).to.eql([]);
			});
	});
});

describe('organisation', function() {
	it('should return content', function() {
		return api.organisations({ uuid: '89a11e71-2651-3ded-bd99-cbf02cddcfb4' })
			.then(function(article) {
				expect(article.title).to.be.a.string;
			});
	});
});

describe('lists', function() {
	it('should return content', function() {
		return api.lists({ uuid: '3c99c2ba-a6ae-11e2-95b1-00144feabdc0' })
			.then(function(list) {
				expect(list.title).to.be.a.string;
				expect(list.items.length).to.equal(3);
			});
	});
});

describe('is-annotated-by', function() {
	it('should return content', function() {
		return api.contentAnnotatedBy({ uuid: '5c7592a8-1f0c-11e4-b0cb-b2227cce2b54' })
			.then(function(articles) {
				expect(articles.length).to.equal(2);
			});
	});
});

describe('search-legacy', function() {
	it("should support elastic search", function() {
		return api.searchLegacy({
			query: 'peopleId:"TnN0ZWluX1BOX1BvbGl0aWNpYW5fMjcx-UE4="'
		})
			.then(function(articles) {
				expect(articles.length).to.equal(50);
				expect(articles.indexCount).to.equal(7783);

			});
	});

	it("should support complex elastic searches", function() {
		sinon.spy(GLOBAL, 'fetch');

		return api.searchLegacy({
			query: { test: true },
			fields: ['test']
		})
			.then(function () {
				var elasticOpts = JSON.parse(GLOBAL.fetch.args[0][1].body);
				expect(elasticOpts.fields[0]).to.equal('test');
				expect(elasticOpts.query.test).to.be.true;
				GLOBAL.fetch.restore();
			});

	});

	it("should ignore items tagged as podcast by default", function() {
		sinon.spy(GLOBAL, 'fetch');

		return api.searchLegacy({ query: 'peopleId:"TnN0ZWluX1BOX1BvbGl0aWNpYW5fMjcx-UE4="' })
			.then(function () {
				var elasticOpts = JSON.parse(GLOBAL.fetch.args[0][1].body);
				expect(elasticOpts.query.bool.must_not.term).to.an('object');
				expect(elasticOpts.query.bool.must_not.term).to.have.keys('item.metadata.sections.term.name');
				GLOBAL.fetch.restore();
			});

	});
});
